@@ -5,17 +5,12 @@ import re
 
 class APIFunction(LambdaFunction):
     def run(self, event, context):
-        print("Running!")
         # Get the calling method and route appropriately.
         method = event["httpMethod"].lower()
 
         # Get get query params to pass in.
         params = self._get_url_params()
-        print("Params:")
-        print(params)
         args = [event["pathParameters"][p] for p in params]
-        print("Args:")
-        print(args)
 
         # TODO: Should use a more elegent method of routing here.
         if method == "post":
@@ -34,6 +29,12 @@ class APIFunction(LambdaFunction):
 
     def create_return(self, status_code=200, body=None):
         return_obj = {"statusCode": status_code}
+        headers = {
+            "Access-Control-Allow-Origin": "*",
+            "Access-Control-Allow-Credentials": "true",
+            "Access-Control-Allow-Headers": "Content-Type",
+        }
+        return_obj["headers"] = headers
         if body:
             return_obj["body"] = json.dumps(body)
         return return_obj
