@@ -126,19 +126,6 @@ class Deployer(object):
             ACL="private", Bucket=f"{self.project_name}-{self.environment}"
         )
 
-        self._build()
-
-        # subprocess.run(
-        #     [
-        #         "sam",
-        #         "package",
-        #         "--s3-bucket",
-        #         f"{self.project_name}-{self.environment}",
-        #         "--template-file",
-        #         "bld.yml",
-        #     ],
-        #     cwd=self.dir,
-        # )
         env_vars = self._get_env_vars()
         overrides = [
             f"ParameterKey={x['alpha_name']},ParameterValue={x['value']}"
